@@ -328,7 +328,7 @@ def insts_status(request, host_id):
                           'uuid': conn.get_uuid(instance),
                           'host': host_id,
                           'dump': conn.get_instance_managed_save_image(instance)
-                          })
+        })
 
     data = json.dumps(instances)
     response = HttpResponse()
@@ -423,7 +423,8 @@ def instance(request, host_id, vname):
                 image = name + "-clone" + "." + suffix
             else:
                 image = disk['image'] + "-clone"
-            clone_disk.append({'dev': disk['dev'], 'storage': disk['storage'], 'image': image})
+            clone_disk.append(
+                {'dev': disk['dev'], 'storage': disk['storage'], 'image': image, 'format': disk['format']})
         return clone_disk
 
     errors = []
@@ -480,7 +481,7 @@ def instance(request, host_id, vname):
         if request.method == 'POST':
             if 'start' in request.POST:
                 conn.start()
-                return HttpResponseRedirect(request.get_full_path())
+                return HttpResponseRedirect(request.get_full_path() + '#shutdown')
             if 'power' in request.POST:
                 if 'shutdown' == request.POST.get('power', ''):
                     conn.shutdown()
@@ -594,7 +595,7 @@ def instance(request, host_id, vname):
                 clone_data['name'] = request.POST.get('name', '')
 
                 for post in request.POST:
-                    if 'disk' in post:
+                    if 'disk' or 'meta' in post:
                         clone_data[post] = request.POST.get(post, '')
 
                 conn.clone_instance(clone_data)
