@@ -18,17 +18,17 @@ import types
 # this should include www.iana.org/assignments/ipv4-address-space
 # and www.iana.org/assignments/multicast-addresses
 IPv4ranges = {
-    '0':                'PUBLIC',   # fall back
-    '00000000':         'PRIVATE',  # 0/8
-    '00001010':         'PRIVATE',  # 10/8
-    '01111111':         'PRIVATE',  # 127.0/8
-    '1':                'PUBLIC',   # fall back
+    '0': 'PUBLIC',  # fall back
+    '00000000': 'PRIVATE',  # 0/8
+    '00001010': 'PRIVATE',  # 10/8
+    '01111111': 'PRIVATE',  # 127.0/8
+    '1': 'PUBLIC',  # fall back
     '1010100111111110': 'PRIVATE',  # 169.254/16
-    '101011000001':     'PRIVATE',  # 172.16/12
+    '101011000001': 'PRIVATE',  # 172.16/12
     '1100000010101000': 'PRIVATE',  # 192.168/16
-    '11011111':         'RESERVED', # 223/8
-    '111':              'RESERVED'  # 224/3
-    }
+    '11011111': 'RESERVED',  # 223/8
+    '111': 'RESERVED'  # 224/3
+}
 
 # Definition of the Ranges for IPv6 IPs
 # see also www.iana.org/assignments/ipv6-address-space,
@@ -36,40 +36,40 @@ IPv4ranges = {
 # www.iana.org/assignments/ipv6-multicast-addresses,
 # www.iana.org/assignments/ipv6-anycast-addresses
 IPv6ranges = {
-    '00000000'              : 'RESERVED',       # ::/8
-    '00000001'              : 'UNASSIGNED',     # 100::/8
-    '0000001'               : 'NSAP',           # 200::/7
-    '0000010'               : 'IPX',            # 400::/7
-    '0000011'               : 'UNASSIGNED',     # 600::/7
-    '00001'                 : 'UNASSIGNED',     # 800::/5
-    '0001'                  : 'UNASSIGNED',     # 1000::/4
-    '0010000000000000'      : 'RESERVED',       # 2000::/16 Reserved
-    '0010000000000001'      : 'ASSIGNABLE',     # 2001::/16 Sub-TLA Assignments [RFC2450]
+    '00000000': 'RESERVED',  # ::/8
+    '00000001': 'UNASSIGNED',  # 100::/8
+    '0000001': 'NSAP',  # 200::/7
+    '0000010': 'IPX',  # 400::/7
+    '0000011': 'UNASSIGNED',  # 600::/7
+    '00001': 'UNASSIGNED',  # 800::/5
+    '0001': 'UNASSIGNED',  # 1000::/4
+    '0010000000000000': 'RESERVED',  # 2000::/16 Reserved
+    '0010000000000001': 'ASSIGNABLE',  # 2001::/16 Sub-TLA Assignments [RFC2450]
     '00100000000000010000000': 'ASSIGNABLE IANA',  # 2001:0000::/29 - 2001:01F8::/29 IANA
-    '00100000000000010000001': 'ASSIGNABLE APNIC', # 2001:0200::/29 - 2001:03F8::/29 APNIC
+    '00100000000000010000001': 'ASSIGNABLE APNIC',  # 2001:0200::/29 - 2001:03F8::/29 APNIC
     '00100000000000010000010': 'ASSIGNABLE ARIN',  # 2001:0400::/29 - 2001:05F8::/29 ARIN
     '00100000000000010000011': 'ASSIGNABLE RIPE',  # 2001:0600::/29 - 2001:07F8::/29 RIPE NCC
-    '0010000000000010'      : '6TO4',           # 2002::/16 "6to4" [RFC3056]
-    '0011111111111110'      : '6BONE',          # 3FFE::/16 6bone Testing [RFC2471]
-    '0011111111111111'      : 'RESERVED',       # 3FFF::/16 Reserved
-    '010'                   : 'GLOBAL-UNICAST', # 4000::/3
-    '011'                   : 'UNASSIGNED',     # 6000::/3
-    '100'                   : 'GEO-UNICAST',    # 8000::/3
-    '101'                   : 'UNASSIGNED',     # A000::/3
-    '110'                   : 'UNASSIGNED',     # C000::/3
-    '1110'                  : 'UNASSIGNED',     # E000::/4
-    '11110'                 : 'UNASSIGNED',     # F000::/5
-    '111110'                : 'UNASSIGNED',     # F800::/6
-    '1111110'               : 'UNASSIGNED',     # FC00::/7
-    '111111100'             : 'UNASSIGNED',     # FE00::/9
-    '1111111010'            : 'LINKLOCAL',      # FE80::/10
-    '1111111011'            : 'SITELOCAL',      # FEC0::/10
-    '11111111'              : 'MULTICAST',      # FF00::/8
-    '0' * 96                : 'IPV4COMP',       # ::/96
-    '0' * 80 + '1' * 16     : 'IPV4MAP',        # ::FFFF:0:0/96
-    '0' * 128               : 'UNSPECIFIED',    # ::/128
-    '0' * 127 + '1'         : 'LOOPBACK'        # ::1/128
-    }
+    '0010000000000010': '6TO4',  # 2002::/16 "6to4" [RFC3056]
+    '0011111111111110': '6BONE',  # 3FFE::/16 6bone Testing [RFC2471]
+    '0011111111111111': 'RESERVED',  # 3FFF::/16 Reserved
+    '010': 'GLOBAL-UNICAST',  # 4000::/3
+    '011': 'UNASSIGNED',  # 6000::/3
+    '100': 'GEO-UNICAST',  # 8000::/3
+    '101': 'UNASSIGNED',  # A000::/3
+    '110': 'UNASSIGNED',  # C000::/3
+    '1110': 'UNASSIGNED',  # E000::/4
+    '11110': 'UNASSIGNED',  # F000::/5
+    '111110': 'UNASSIGNED',  # F800::/6
+    '1111110': 'UNASSIGNED',  # FC00::/7
+    '111111100': 'UNASSIGNED',  # FE00::/9
+    '1111111010': 'LINKLOCAL',  # FE80::/10
+    '1111111011': 'SITELOCAL',  # FEC0::/10
+    '11111111': 'MULTICAST',  # FF00::/8
+    '0' * 96: 'IPV4COMP',  # ::/96
+    '0' * 80 + '1' * 16: 'IPV4MAP',  # ::FFFF:0:0/96
+    '0' * 128: 'UNSPECIFIED',  # ::/128
+    '0' * 127 + '1': 'LOOPBACK'  # ::1/128
+}
 
 
 class IPint:
@@ -157,7 +157,7 @@ class IPint:
                 # make sure the broadcast is the same as the last ip
                 # otherwise it will return /16 for something like:
                 # 192.168.0.0-192.168.191.255
-                if IP('%s/%s' % (ip, 32-netbits)).broadcast().int() != last:
+                if IP('%s/%s' % (ip, 32 - netbits)).broadcast().int() != last:
                     raise ValueError, \
                         "the range %s is not on a network boundary." % data
             elif len(x) == 1:
@@ -199,7 +199,7 @@ class IPint:
                 self.ip = self.ip & _prefixlenToNetmask(self._prefixlen, self._ipversion)
 
             if not _checkNetaddrWorksWithPrefixlen(self.ip,
-            self._prefixlen, self._ipversion):
+                                                   self._prefixlen, self._ipversion):
                 raise ValueError, "%s has invalid prefix length (%s)" % (repr(self), self._prefixlen)
 
     def int(self):
@@ -256,7 +256,7 @@ class IPint:
         """
 
         if (self._ipversion == 4 and self._prefixlen == 32) or \
-           (self._ipversion == 6 and self._prefixlen == 128):
+                (self._ipversion == 6 and self._prefixlen == 128):
             if self.NoPrefixForSingleIp:
                 want = 0
         if want == None:
@@ -268,7 +268,7 @@ class IPint:
                 # this should work with IP and IPint
                 netmask = self.netmask()
                 if type(netmask) != types.IntType \
-                and type(netmask) != types.LongType:
+                        and type(netmask) != types.LongType:
                     netmask = netmask.int()
                 return "/%s" % (intToIp(netmask, self._ipversion))
             elif want == 3:
@@ -279,21 +279,20 @@ class IPint:
         else:
             return ''
 
-        # We have different flavours to convert to:
-        # strFullsize   127.0.0.1    2001:0658:022a:cafe:0200:c0ff:fe8d:08fa
-        # strNormal     127.0.0.1    2001:658:22a:cafe:200:c0ff:fe8d:08fa
-        # strCompressed 127.0.0.1    2001:658:22a:cafe::1
-        # strHex        0x7F000001L  0x20010658022ACAFE0200C0FFFE8D08FA
-        # strDec        2130706433   42540616829182469433547974687817795834
+            # We have different flavours to convert to:
+            # strFullsize   127.0.0.1    2001:0658:022a:cafe:0200:c0ff:fe8d:08fa
+            # strNormal     127.0.0.1    2001:658:22a:cafe:200:c0ff:fe8d:08fa
+            # strCompressed 127.0.0.1    2001:658:22a:cafe::1
+            # strHex        0x7F000001L  0x20010658022ACAFE0200C0FFFE8D08FA
+            # strDec        2130706433   42540616829182469433547974687817795834
 
-    def strBin(self, wantprefixlen = None):
+    def strBin(self, wantprefixlen=None):
         """Return a string representation as a binary value.
 
         >>> print IP('127.0.0.1').strBin()
         01111111000000000000000000000001
         """
 
-
         if self._ipversion == 4:
             bits = 32
         elif self._ipversion == 6:
@@ -304,9 +303,9 @@ class IPint:
         if self.WantPrefixLen == None and wantprefixlen == None:
             wantprefixlen = 0
         ret = _intToBin(self.ip)
-        return  '0' * (bits - len(ret)) + ret + self._printPrefix(wantprefixlen)
+        return '0' * (bits - len(ret)) + ret + self._printPrefix(wantprefixlen)
 
-    def strCompressed(self, wantprefixlen = None):
+    def strCompressed(self, wantprefixlen=None):
         """Return a string representation in compressed format using '::' Notation.
 
         >>> IP('127.0.0.1').strCompressed()
@@ -341,7 +340,7 @@ class IPint:
                 # now we need hextets as strings
                 hextets = [x for x in self.strNormal(0).split(':')]
                 while compressionpos < len(hextets) and hextets[compressionpos] == '0':
-                    del(hextets[compressionpos])
+                    del (hextets[compressionpos])
                 hextets.insert(compressionpos, '')
                 if compressionpos + 1 >= len(hextets):
                     hextets.append('')
@@ -351,7 +350,7 @@ class IPint:
             else:
                 return self.strNormal(0) + self._printPrefix(wantprefixlen)
 
-    def strNormal(self, wantprefixlen = None):
+    def strNormal(self, wantprefixlen=None):
         """Return a string representation in the usual format.
 
         >>> print IP('127.0.0.1').strNormal()
@@ -370,11 +369,9 @@ class IPint:
         else:
             raise ValueError, "only IPv4 and IPv6 supported"
 
-
-
         return ret + self._printPrefix(wantprefixlen)
 
-    def strFullsize(self, wantprefixlen = None):
+    def strFullsize(self, wantprefixlen=None):
         """Return a string representation in the non-mangled format.
 
         >>> print IP('127.0.0.1').strFullsize()
@@ -388,7 +385,7 @@ class IPint:
 
         return intToIp(self.ip, self._ipversion).lower() + self._printPrefix(wantprefixlen)
 
-    def strHex(self, wantprefixlen = None):
+    def strHex(self, wantprefixlen=None):
         """Return a string representation in hex format in lower case.
 
         >>> IP('127.0.0.1').strHex()
@@ -405,7 +402,7 @@ class IPint:
             x = x[:-1]
         return x.lower() + self._printPrefix(wantprefixlen)
 
-    def strDec(self, wantprefixlen = None):
+    def strDec(self, wantprefixlen=None):
         """Return a string representation in decimal format.
 
         >>> print IP('127.0.0.1').strDec()
@@ -417,7 +414,7 @@ class IPint:
         if self.WantPrefixLen == None and wantprefixlen == None:
             wantprefixlen = 0
 
-        x =  str(self.ip)
+        x = str(self.ip)
         if x[-1] == 'L':
             x = x[:-1]
         return x + self._printPrefix(wantprefixlen)
@@ -563,7 +560,6 @@ class IPint:
         return self.ip + long(key)
 
 
-
     def __contains__(self, item):
         """Called to implement membership test operators.
 
@@ -631,7 +627,7 @@ class IPint:
         IP('10.0.0.0/24')
         """
 
-        return("IPint('%s')" % (self.strCompressed(1)))
+        return ("IPint('%s')" % (self.strCompressed(1)))
 
 
     def __cmp__(self, other):
@@ -769,17 +765,17 @@ class IP(IPint):
         if self._ipversion == 4:
             ret = []
             # TODO: Refactor. Add support for IPint objects
-            if self.len() < 2**8:
+            if self.len() < 2 ** 8:
                 for x in self:
                     ret.append(x.reverseName())
-            elif self.len() < 2**16L:
-                for i in range(0, self.len(), 2**8):
+            elif self.len() < 2 ** 16L:
+                for i in range(0, self.len(), 2 ** 8):
                     ret.append(self[i].reverseName()[2:])
-            elif self.len() < 2**24L:
-                for i in range(0, self.len(), 2**16):
+            elif self.len() < 2 ** 24L:
+                for i in range(0, self.len(), 2 ** 16):
                     ret.append(self[i].reverseName()[4:])
             else:
-                for i in range(0, self.len(), 2**24):
+                for i in range(0, self.len(), 2 ** 24):
                     ret.append(self[i].reverseName()[6:])
             return ret
         elif self._ipversion == 6:
@@ -797,7 +793,6 @@ class IP(IPint):
             raise ValueError, "only IPv4 and IPv6 supported"
 
 
-
     def reverseName(self):
         """Return the value for reverse lookup/PTR records as RFC 2317 look alike.
 
@@ -819,7 +814,8 @@ class IP(IPint):
             s.reverse()
             first_byte_index = int(4 - (self._prefixlen / 8))
             if self._prefixlen % 8 != 0:
-                nibblepart = "%s-%s" % (s[3-(self._prefixlen / 8)], intToIp(self.ip + self.len() - 1, 4).split('.')[-1])
+                nibblepart = "%s-%s" % (
+                s[3 - (self._prefixlen / 8)], intToIp(self.ip + self.len() - 1, 4).split('.')[-1])
                 if nibblepart[-1] == 'l':
                     nibblepart = nibblepart[:-1]
                 nibblepart += '.'
@@ -886,7 +882,7 @@ class IP(IPint):
         IP('10.0.0.0/8')
         """
 
-        return("IP('%s')" % (self.strCompressed(1)))
+        return ("IP('%s')" % (self.strCompressed(1)))
 
     def __add__(self, other):
         """Emulate numeric objects through network aggregation"""
@@ -957,7 +953,7 @@ def _parseAddressIPv6(ipstr):
     """
 
     # Split string into a list, example:
-    #   '1080:200C::417A' => ['1080', '200C', '417A'] and fill_pos=2
+    # '1080:200C::417A' => ['1080', '200C', '417A'] and fill_pos=2
     # and fill_pos is the position of '::' in the list
     items = []
     index = 0
@@ -977,10 +973,10 @@ def _parseAddressIPv6(ipstr):
             raise ValueError("%r: Invalid IPv6 address" % ipstr)
         if pos != -1:
             items.append(text[:pos])
-            if text[pos:pos+2] == "::":
+            if text[pos:pos + 2] == "::":
                 index += pos
             else:
-                index += pos+1
+                index += pos + 1
 
             if index == len(ipstr):
                 # Invalid IPv6, eg. '1::2:'
@@ -991,7 +987,7 @@ def _parseAddressIPv6(ipstr):
 
     if items and '.' in items[-1]:
         # IPv6 ending with IPv4 like '::ffff:192.168.0.1'
-        if not (fill_pos <= len(items)-1):
+        if not (fill_pos <= len(items) - 1):
             # Invalid IPv6: 'ffff:192.168.0.1::'
             raise ValueError("%r: Invalid IPv6 address: '::' after IPv4" % ipstr)
         value = parseAddress(items[-1])[0]
@@ -1003,7 +999,7 @@ def _parseAddressIPv6(ipstr):
         diff = 8 - len(items)
         if diff <= 0:
             raise ValueError("%r: Invalid IPv6 address: '::' is not needed" % ipstr)
-        items = items[:fill_pos] + ['0']*diff + items[fill_pos:]
+        items = items[:fill_pos] + ['0'] * diff + items[fill_pos:]
 
     # Here we have a list of 8 strings
     if len(items) != 8:
@@ -1016,7 +1012,7 @@ def _parseAddressIPv6(ipstr):
     for item in items:
         try:
             item = int(item, 16)
-            error = not(0 <= item <= 0xFFFF)
+            error = not (0 <= item <= 0xFFFF)
         except ValueError:
             error = True
         if error:
@@ -1025,6 +1021,7 @@ def _parseAddressIPv6(ipstr):
         index += 1
     return value
 
+
 def parseAddress(ipstr):
     """
     Parse a string and return the corresponding IP address (as integer)
@@ -1072,7 +1069,7 @@ def parseAddress(ipstr):
         # assume IPv6 in pure hexadecimal notation
         return (long(ipstr, 16), 6)
 
-    elif  ipstr.find('.') != -1 or (len(ipstr) < 4 and int(ipstr) < 256):
+    elif ipstr.find('.') != -1 or (len(ipstr) < 4 and int(ipstr) < 256):
         # assume IPv4  ('127' gets interpreted as '127.0.0.0')
         bytes = ipstr.split('.')
         if len(bytes) > 4:
@@ -1128,6 +1125,7 @@ def intToIp(ip, version):
 
     return ret
 
+
 def _ipVersionToLen(version):
     """Return number of bits in address for a certain IP version.
 
@@ -1162,9 +1160,10 @@ def _countFollowingZeros(l):
 
 
 _BitTable = {'0': '0000', '1': '0001', '2': '0010', '3': '0011',
-            '4': '0100', '5': '0101', '6': '0110', '7': '0111',
-            '8': '1000', '9': '1001', 'a': '1010', 'b': '1011',
-            'c': '1100', 'd': '1101', 'e': '1110', 'f': '1111'}
+             '4': '0100', '5': '0101', '6': '0110', '7': '0111',
+             '8': '1000', '9': '1001', 'a': '1010', 'b': '1011',
+             'c': '1100', 'd': '1101', 'e': '1110', 'f': '1111'}
+
 
 def _intToBin(val):
     """Return the binary representation of an integer as string."""
@@ -1185,6 +1184,7 @@ def _intToBin(val):
         ret = ret[1:]
     return ret
 
+
 def _count1Bits(num):
     """Find the highest bit set to 1 in an integer."""
     ret = 0
@@ -1193,6 +1193,7 @@ def _count1Bits(num):
         ret += 1
     return ret
 
+
 def _count0Bits(num):
     """Find the highest bit set to 0 in an integer."""
 
@@ -1235,7 +1236,7 @@ def _checkPrefix(ip, prefixlen, version):
         zbits = bits + 1
     else:
         zbits = _count0Bits(ip)
-    if zbits <  bits - prefixlen:
+    if zbits < bits - prefixlen:
         return 0
     else:
         return 1
@@ -1292,12 +1293,14 @@ def _prefixlenToNetmask(prefixlen, version):
         return 0
     elif prefixlen < 0:
         raise ValueError, "Prefixlen must be > 0"
-    return ((2L<<prefixlen-1)-1) << (_ipVersionToLen(version) - prefixlen)
+    return ((2L << prefixlen - 1) - 1) << (_ipVersionToLen(version) - prefixlen)
 
 
 if __name__ == "__main__":
     import doctest
+
     failure, nbtest = doctest.testmod()
     if failure:
         import sys
+
         sys.exit(1)
